From 9b2b8c8652032c216c4f14d54fa24a2492c8325b Mon Sep 17 00:00:00 2001
From: Lukas Larsson <lukas@erlang-solutions.com>
Date: Thu, 22 Sep 2011 09:47:42 +0200
Subject: Extend slave start timeout for windows tests

---
 lib/common_test/test/ct_test_support.erl | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

(limited to 'lib')

diff --git a/lib/common_test/test/ct_test_support.erl b/lib/common_test/test/ct_test_support.erl
index 31381abc40..e85e8e6ad3 100644
--- a/lib/common_test/test/ct_test_support.erl
+++ b/lib/common_test/test/ct_test_support.erl
@@ -25,6 +25,7 @@
 
 -include_lib("test_server/include/test_server.hrl").
 -include_lib("common_test/include/ct_event.hrl").
+-include_lib("common_test/include/ct.hrl").
 
 -export([init_per_suite/1, init_per_suite/2, end_per_suite/1,
 	 init_per_testcase/2, end_per_testcase/2,
@@ -46,9 +47,10 @@ init_per_suite(Config) ->
 init_per_suite(Config, Level) ->
     case os:type() of
 	{win32, _} ->
-	    %% Extend timeout for windows as starting node
+	    %% Extend timeout to 1 hour for windows as starting node
 	    %% can take a long time there
-	    test_server:timetrap( 120000 * test_server:timetrap_scale_factor());
+	    test_server:timetrap( 60*60*1000 * 
+				      test_server:timetrap_scale_factor());
 	_ ->
 	    ok
     end,
-- 
cgit v1.2.3


From 8b06e8921f7e2f9d907df7edd8daf11ee24a0a1e Mon Sep 17 00:00:00 2001
From: Lukas Larsson <lukas@erlang-solutions.com>
Date: Mon, 26 Sep 2011 19:04:25 +0200
Subject: Extend time to wait for zone files to be loaded

This change was made in order to make slow solaris machines
work.
---
 lib/kernel/test/inet_res_SUITE_data/run-named | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

(limited to 'lib')

diff --git a/lib/kernel/test/inet_res_SUITE_data/run-named b/lib/kernel/test/inet_res_SUITE_data/run-named
index b418607d48..7caa3756ef 100755
--- a/lib/kernel/test/inet_res_SUITE_data/run-named
+++ b/lib/kernel/test/inet_res_SUITE_data/run-named
@@ -2,7 +2,7 @@
 ##
 ## %CopyrightBegin%
 ## 
-## Copyright Ericsson AB 2009. All Rights Reserved.
+## Copyright Ericsson AB 2009-2011. All Rights Reserved.
 ## 
 ## The contents of this file are subject to the Erlang Public License,
 ## Version 1.1, (the "License"); you may not use this file except in
@@ -155,7 +155,7 @@ $NAMED $NAMED_FG -c "$CONF_FILE" >"$LOG_FILE" 2>&1 </dev/null &
 NAMED=$!
 trap "kill -TERM $NAMED >/dev/null 2>&1; wait $NAMED >/dev/null 2>&1" \
     0 1 2 3 15
-sleep 1 # Give name server time to load its zone files
+sleep 2 # Give name server time to load its zone files
 echo "Running: Enter \`\`quit'' to terminate nameserver[$NAMED]..."
 while read LINE; do 
     test :"$LINE" = :'quit' && break
-- 
cgit v1.2.3


From a176db06b4de2354a385813409a3340c85c3b341 Mon Sep 17 00:00:00 2001
From: Lukas Larsson <lukas@erlang-solutions.com>
Date: Mon, 26 Sep 2011 19:13:03 +0200
Subject: Use static port for old solaris versions

Solaris version before 10 have some problem with releasing
addresses after doing a gen_udp:open, which causes inet_res
to get a econnrefused. With this fix we hope that the static
port will not collide with anything.
---
 lib/kernel/test/inet_res_SUITE.erl | 12 +++++++++---
 1 file changed, 9 insertions(+), 3 deletions(-)

(limited to 'lib')

diff --git a/lib/kernel/test/inet_res_SUITE.erl b/lib/kernel/test/inet_res_SUITE.erl
index 6064a9b2d9..8a3d220e46 100644
--- a/lib/kernel/test/inet_res_SUITE.erl
+++ b/lib/kernel/test/inet_res_SUITE.erl
@@ -117,9 +117,15 @@ ns_init(ZoneDir, PrivDir, DataDir) ->
     case os:type() of
 	{unix,_} when ZoneDir =:= undefined -> undefined;
 	{unix,_} ->
-	    {ok,S} = gen_udp:open(0, [{reuseaddr,true}]),
-	    {ok,PortNum} = inet:port(S),
-	    gen_udp:close(S),
+	    PortNum = case {os:type(),os:version()} of
+			  {{unix,solaris},{M,V,_}} when M =< 5, V < 10 ->
+			      11895 + random:uniform(100);
+			  _ ->
+			      {ok,S} = gen_udp:open(0, [{reuseaddr,true}]),
+			      {ok,PNum} = inet:port(S),
+			      gen_udp:close(S),
+			      PNum
+		      end,
 	    RunNamed = filename:join(DataDir, ?RUN_NAMED),
 	    NS = {{127,0,0,1},PortNum},
 	    P = erlang:open_port({spawn_executable,RunNamed},
-- 
cgit v1.2.3


From 22a3818adb4e3433d7ab9f34e0ade06fdf10d8d6 Mon Sep 17 00:00:00 2001
From: Lukas Larsson <lukas@erlang-solutions.com>
Date: Tue, 27 Sep 2011 12:03:04 +0200
Subject: Skip getaddr_v6 test if on the ipv4_only host

---
 lib/kernel/test/inet_SUITE.erl | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

(limited to 'lib')

diff --git a/lib/kernel/test/inet_SUITE.erl b/lib/kernel/test/inet_SUITE.erl
index 1bb173a3ac..aaa20b7398 100644
--- a/lib/kernel/test/inet_SUITE.erl
+++ b/lib/kernel/test/inet_SUITE.erl
@@ -294,7 +294,7 @@ t_getaddr_v6(Config) when is_list(Config) ->
     ?line {Name,FullName,IPStr,_IP,_,IP_46_Str,IP46} =
 	ct:get_config(test_host_ipv4_only),
     case {inet:getaddr(IP_46_Str, inet6),inet:getaddr(Name, inet6)} of
-	{{ok,IP46},{ok,_}} -> 
+	{{ok,IP46},{ok,V4Addr}} when V4Addr /= {0,0,0,0,0,0,0,1} ->
 	    %% Since we suceeded in parsing an IPv6 address string and
 	    %% look up the name, this computer fully supports IPv6.
 	    ?line {ok,IP46} = inet:getaddr(IP46, inet6),
-- 
cgit v1.2.3


From d41617d9969253d9e66270beebac843865036baa Mon Sep 17 00:00:00 2001
From: Lukas Larsson <lukas@erlang-solutions.com>
Date: Tue, 27 Sep 2011 17:14:08 +0200
Subject: Skip create_big_boot on platforms without crypto

This has to be done as many other applications depend
on that crypto is present.
---
 lib/kernel/test/code_SUITE.erl | 7 +++++++
 1 file changed, 7 insertions(+)

(limited to 'lib')

diff --git a/lib/kernel/test/code_SUITE.erl b/lib/kernel/test/code_SUITE.erl
index f7d56eed48..b677f34ed0 100644
--- a/lib/kernel/test/code_SUITE.erl
+++ b/lib/kernel/test/code_SUITE.erl
@@ -81,6 +81,13 @@ init_per_suite(Config) ->
 end_per_suite(Config) ->
     Config.
 
+init_per_testcase(big_boot_embedded, Config) ->
+    case catch crypto:start() of
+	ok ->
+	    init_per_testcase(do_big_boot_embedded, Config);
+	_Else ->
+	    {skip, "Needs crypto!"}
+    end;
 init_per_testcase(_Func, Config) ->
     Dog=?t:timetrap(?t:minutes(5)),
     P=code:get_path(),
-- 
cgit v1.2.3


From bb98bf86894527817e0d00aa87286a4291937d03 Mon Sep 17 00:00:00 2001
From: Lukas Larsson <lukas@erlang-solutions.com>
Date: Tue, 27 Sep 2011 12:20:41 +0200
Subject: Remove test_server path instead of cwd for clash test

With the introduction of common_test as test framework
the working directory of the tests changed to be the
emulator_test directory. So we now have to remove the
../test_server directory instead. This change only affect
tests run with a emulator which has not been installed.
---
 lib/kernel/test/code_SUITE.erl | 14 ++++++++------
 1 file changed, 8 insertions(+), 6 deletions(-)

(limited to 'lib')

diff --git a/lib/kernel/test/code_SUITE.erl b/lib/kernel/test/code_SUITE.erl
index 86cccebc29..f7d56eed48 100644
--- a/lib/kernel/test/code_SUITE.erl
+++ b/lib/kernel/test/code_SUITE.erl
@@ -573,11 +573,13 @@ add_del_path(Config) when is_list(Config) ->
 clash(Config) when is_list(Config) ->
     DDir = ?config(data_dir,Config)++"clash/",
     P = code:get_path(),
+    [TestServerPath|_] = [Path || Path <- code:get_path(), 
+				  re:run(Path,"test_server/?$",[]) /= nomatch],
 
     %% test non-clashing entries
 
-    %% remove "." to prevent clash with test-server path
-    ?line true = code:del_path("."),
+    %% remove TestServerPath to prevent clash with test-server path
+    ?line true = code:del_path(TestServerPath),
     ?line true = code:add_path(DDir++"foobar-0.1/ebin"),
     ?line true = code:add_path(DDir++"zork-0.8/ebin"),
     test_server:capture_start(),
@@ -589,8 +591,8 @@ clash(Config) when is_list(Config) ->
 
     %% test clashing entries
 
-    %% remove "." to prevent clash with test-server path
-    ?line true = code:del_path("."),
+    %% remove TestServerPath to prevent clash with test-server path
+    ?line true = code:del_path(TestServerPath),
     ?line true = code:add_path(DDir++"foobar-0.1/ebin"),
     ?line true = code:add_path(DDir++"foobar-0.1.ez/foobar-0.1/ebin"),
     test_server:capture_start(),
@@ -603,9 +605,9 @@ clash(Config) when is_list(Config) ->
 
     %% test "Bad path can't read"
 
     %% remove "." to prevent clash with test-server path
     Priv = ?config(priv_dir, Config),
-    ?line true = code:del_path("."),
+    ?line true = code:del_path(TestServerPath),
     TmpEzFile = Priv++"foobar-0.tmp.ez",
     ?line {ok, _} = file:copy(DDir++"foobar-0.1.ez", TmpEzFile),
     ?line true = code:add_path(TmpEzFile++"/foobar-0.1/ebin"),
@@ -603,9 +605,9 @@ clash(Config) when is_list(Config) ->
     %% test "Bad path can't read"
 
-    %% remove "." to prevent clash with test-server path
+    %% remove TestServerPath to prevent clash with test-server path
     Priv = ?config(priv_dir, Config),
-- 
cgit v1.2.3